#
# spec file for package python-restructuredtext_lint
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without libalternatives
Name:           python-restructuredtext_lint
Version:        1.4.0
Release:        2.1
Summary:        Linter for reStructuredText
License:        Unlicense
Group:          Development/Languages/Python
URL:            https://github.com/twolfson/restructuredtext-lint
Source:         https://files.pythonhosted.org/packages/source/r/restructuredtext_lint/restructuredtext_lint-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  alts
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       alts
Requires:       python-docutils >= 0.11
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module docutils >= 0.11}
# /SECTION
%python_subpackages

%description
Linter for reStructuredText.

This was created out of frustration with PyPI; it sucks finding out
your reST is invalid **after** uploading it. It is being developed
in junction with a Sublime Text linter.

%prep
%setup -q -n restructuredtext_lint-%{version}
find . | grep -E "(__pycache__|\.pyc|\.pyo$)" | xargs rm -rf

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/rst-lint
%python_clone -a %{buildroot}%{_bindir}/restructuredtext-lint
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitelib}
$python -m unittest discover
}

%pre
%python_libalternatives_reset_alternative rst-lint
%python_libalternatives_reset_alternative restructuredtext-lint

%files %{python_files}
%doc CHANGELOG.rst README.rst
%license UNLICENSE
%python_alternative %{_bindir}/restructuredtext-lint
%python_alternative %{_bindir}/rst-lint
%{python_sitelib}/restructuredtext_lint
%{python_sitelib}/restructuredtext_lint-%{version}*-info

%changelog
* Wed Jun 11 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build and libalternatives
* Fri Oct  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.4.0
  - Fixed non-zero exit code for missing files/directories. Fixes #58
- Update to version 1.3.2
  - Added "Other tools" section to README. Replacement for #57
- Update to version 1.3.1
  - Removed .pyc files from distribution. Fixes #56
* Tue May 19 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Mon Mar 25 2019 John Vandenberg <jayvdb@gmail.com>
- Removed no longer needed python37.patch
- Update to v1.3.0
  * Added Python 3.7 support
* Thu Feb 14 2019 John Vandenberg <jayvdb@gmail.com>
- Remove unused dependency on PyYAML
- Update to v1.2.2
  * Dropped PyYAML dev dependency by simplifying one test case
- Freshen python37.patch
* Wed Jan  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to build with python 3.7:
  * python37.patch
* Wed Jan  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.1:
  * Added directory support via @dhruvsomani in #48. Fixes #38
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu May 24 2018 toddrme2178@gmail.com
- Update to 1.1.3
  * Updated documentation and typos
- spec file cleanups
* Thu Nov 16 2017 toddrme2178@gmail.com
- Initial version
